==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/WebColumnMovingStartEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebColumnDescriptionMetadata } from "./WebColumnDescriptionMetadata";
import { WebBaseEventArgsDetailDescriptionMetadata } from "./WebBaseEventArgsDetailDescriptionMetadata";
import { WebColumnMovingStartEventArgsDetailDescription } from "./WebColumnMovingStartEventArgsDetailDescription";
/**
 * @hidden
 */
export let WebColumnMovingStartEventArgsDetailDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebColumnMovingStartEventArgsDetailDescriptionMetadata extends Base {
        static b(a) {
            if (WebColumnMovingStartEventArgsDetailDescriptionMetadata.a == null) {
                WebColumnMovingStartEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebColumnMovingStartEventArgsDetailDescriptionMetadata.c(WebColumnMovingStartEventArgsDetailDescriptionMetadata.a);
            }
            if (a.j(WebColumnMovingStartEventArgsDetailDescriptionMetadata.a)) {
                return;
            }
            a.y(WebColumnMovingStartEventArgsDetailDescriptionMetadata.a);
            WebColumnDescriptionMetadata.d(a);
        }
        static c(a) {
            WebBaseEventArgsDetailDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:ColumnMovingStartEventArgsDetail");
            a.item("__packageNameWC", "String:grids");
            a.item("__isPlainObject", "Boolean");
            a.item("Source", "ExportedType:WebColumn");
        }
        static d(a) {
            WebColumnMovingStartEventArgsDetailDescriptionMetadata.b(a);
            a.aa("WebColumnMovingStartEventArgsDetail", () => new WebColumnMovingStartEventArgsDetailDescription());
            a.z("WebColumnMovingStartEventArgsDetail", WebColumnMovingStartEventArgsDetailDescriptionMetadata.a);
        }
    }
    WebColumnMovingStartEventArgsDetailDescriptionMetadata.$t = /*@__PURE__*/ markType(WebColumnMovingStartEventArgsDetailDescriptionMetadata, 'WebColumnMovingStartEventArgsDetailDescriptionMetadata');
    WebColumnMovingStartEventArgsDetailDescriptionMetadata.a = null;
    return WebColumnMovingStartEventArgsDetailDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebColumnMovingStartEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebColumnDescriptionMetadata } from "./WebColumnDescriptionMetadata";
import { WebBaseEventArgsDetailDescriptionMetadata } from "./WebBaseEventArgsDetailDescriptionMetadata";
import { WebColumnMovingStartEventArgsDetailDescription } from "./WebColumnMovingStartEventArgsDetailDescription";
/**
 * @hidden
 */
export let WebColumnMovingStartEventArgsDetailDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebColumnMovingStartEventArgsDetailDescriptionMetadata extends Base {
        static b(a) {
            if (WebColumnMovingStartEventArgsDetailDescriptionMetadata.a == null) {
                WebColumnMovingStartEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebColumnMovingStartEventArgsDetailDescriptionMetadata.c(WebColumnMovingStartEventArgsDetailDescriptionMetadata.a);
            }
            if (a.k(WebColumnMovingStartEventArgsDetailDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebColumnMovingStartEventArgsDetailDescriptionMetadata.a);
            WebColumnDescriptionMetadata.d(a);
        }
        static c(a) {
            WebBaseEventArgsDetailDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:ColumnMovingStartEventArgsDetail");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Source", "ExportedType:WebColumn");
        }
        static d(a) {
            WebColumnMovingStartEventArgsDetailDescriptionMetadata.b(a);
            a.ac("WebColumnMovingStartEventArgsDetail", () => new WebColumnMovingStartEventArgsDetailDescription());
            a.ab("WebColumnMovingStartEventArgsDetail", WebColumnMovingStartEventArgsDetailDescriptionMetadata.a);
        }
    }
    WebColumnMovingStartEventArgsDetailDescriptionMetadata.$t = /*@__PURE__*/ markType(WebColumnMovingStartEventArgsDetailDescriptionMetadata, 'WebColumnMovingStartEventArgsDetailDescriptionMetadata');
    WebColumnMovingStartEventArgsDetailDescriptionMetadata.a = null;
    return WebColumnMovingStartEventArgsDetailDescriptionMetadata;
})();
